@@ -61,6 +61,28 @@ impl super::Kubectl {
         }
     }
 
+    pub fn daemonsets<'a>(
+        &self,
+        namespace: impl Into<Option<&'a str>>,
+    ) -> api::Api<appsv1::DaemonSet> {
+        if let Some(namespace) = namespace.into() {
+            self.namespaced_api::<appsv1::DaemonSet>(namespace)
+        } else {
+            self.default_namespaced_api::<appsv1::DaemonSet>()
+        }
+    }
+
+    pub fn deployments<'a>(
+        &self,
+        namespace: impl Into<Option<&'a str>>,
+    ) -> api::Api<appsv1::Deployment> {
+        if let Some(namespace) = namespace.into() {
+            self.namespaced_api::<appsv1::Deployment>(namespace)
+        } else {
+            self.default_namespaced_api::<appsv1::Deployment>()
+        }
+    }
+
     pub fn crds(&self) -> api::Api<apiextensionsv1::CustomResourceDefinition> {
         self.api::<apiextensionsv1::CustomResourceDefinition>()
     }
@@ -77,6 +99,14 @@ impl super::Kubectl {
         }
     }
 
+    pub fn pods<'a>(&self, namespace: impl Into<Option<&'a str>>) -> api::Api<corev1::Pod> {
+        if let Some(namespace) = namespace.into() {
+            self.namespaced_api::<corev1::Pod>(namespace)
+        } else {
+            self.default_namespaced_api::<corev1::Pod>()
+        }
+    }
+
     pub async fn get_secret(&self, name: &str) -> kube::Result<corev1::Secret> {
         self.secrets(None).get(name).await
     }
@@ -113,6 +143,39 @@ impl super::Kubectl {
         Ok(cm)
     }
 
+    pub async fn list_daemonsets<'a>(
+        &self,
+        namespace: impl Into<Option<&'a str>>,
+    ) -> kube::Result<Vec<appsv1::DaemonSet>> {
+        let lp = self.list_params();
+        self.daemonsets(namespace)
+            .list(&lp)
+            .await
+            .map(|object| object.items)
+    }
+
+    pub async fn list_deployments<'a>(
+        &self,
+        namespace: impl Into<Option<&'a str>>,
+    ) -> kube::Result<Vec<appsv1::Deployment>> {
+        let lp = self.list_params();
+        self.deployments(namespace)
+            .list(&lp)
+            .await
+            .map(|object| object.items)
+    }
+
+    pub async fn list_pods<'a>(
+        &self,
+        namespace: impl Into<Option<&'a str>>,
+    ) -> kube::Result<Vec<corev1::Pod>> {
+        let lp = self.list_params();
+        self.pods(namespace)
+            .list(&lp)
+            .await
+            .map(|object| object.items)
+    }
+
     pub async fn list_crds(&self) -> kube::Result<Vec<apiextensionsv1::CustomResourceDefinition>> {
         let lp = self.list_params();
         self.crds().list(&lp).await.map(|object| object.items)
